public inbox for gcc-cvs@sourceware.org
help / color / mirror / Atom feed
* [gcc r12-6066] c++: don't ICE on NAMESPACE_DECL inside FUNCTION_DECL
@ 2021-12-19 20:09 Matthias Kretz
  0 siblings, 0 replies; only message in thread
From: Matthias Kretz @ 2021-12-19 20:09 UTC (permalink / raw)
  To: gcc-cvs

https://gcc.gnu.org/g:6bcb6ed5a44b6f271891246ef7ae568bfdc14e9c

commit r12-6066-g6bcb6ed5a44b6f271891246ef7ae568bfdc14e9c
Author: Matthias Kretz <m.kretz@gsi.de>
Date:   Wed Dec 15 09:45:06 2021 +0100

    c++: don't ICE on NAMESPACE_DECL inside FUNCTION_DECL
    
    Code like
      void swap() {
        namespace __variant = __detail::__variant;
        ...
      }
    create a NAMESPACE_DECL where the CP_DECL_CONTEXT is a FUNCTION_DECL.
    DECL_TEMPLATE_INFO fails on NAMESPACE_DECL and therefore must be handled
    first in the assertion.
    
    Signed-off-by: Matthias Kretz <m.kretz@gsi.de>
    
    gcc/cp/ChangeLog:
    
            * module.cc (trees_out::get_merge_kind): NAMESPACE_DECLs also
            cannot have a DECL_TEMPLATE_INFO.

Diff:
---
 gcc/cp/module.cc | 5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)

diff --git a/gcc/cp/module.cc b/gcc/cp/module.cc
index f3e7af22699..8451e3dcc90 100644
--- a/gcc/cp/module.cc
+++ b/gcc/cp/module.cc
@@ -10067,9 +10067,10 @@ trees_out::get_merge_kind (tree decl, depset *dep)
       tree ctx = CP_DECL_CONTEXT (decl);
       if (TREE_CODE (ctx) == FUNCTION_DECL)
 	{
-	  /* USING_DECLs cannot have DECL_TEMPLATE_INFO -- this isn't
-	     permitting them to have one.   */
+	  /* USING_DECLs and NAMESPACE_DECLs cannot have DECL_TEMPLATE_INFO --
+	     this isn't permitting them to have one.   */
 	  gcc_checking_assert (TREE_CODE (decl) == USING_DECL
+			       || TREE_CODE (decl) == NAMESPACE_DECL
 			       || !DECL_LANG_SPECIFIC (decl)
 			       || !DECL_TEMPLATE_INFO (decl));


^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2021-12-19 20:09 UTC | newest]

Thread overview: (only message) (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2021-12-19 20:09 [gcc r12-6066] c++: don't ICE on NAMESPACE_DECL inside FUNCTION_DECL Matthias Kretz

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).